@@ -31,7 +31,7 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
-        global feature_name, alarm, alarm_api, message_param, user_id, notebook_info
+        global feature_name, alarm, alarm_api, message_param, user_id, notebook_info, run_meta
         super().__init__()
 
         feature_name = None
@@ -42,6 +42,8 @@ class accuinsight(Common):
         alarm_api = self.workspace_alarm_api
         notebook_info = self.notebook_info
 
+        run_meta = None
+
     def get_file(self, storage_json_file_name=None):
         global save_path, StorageInfo, target_name
         save_path, StorageInfo, target_name = super().get_file(storage_json_file_name)
@@ -88,6 +90,10 @@ class accuinsight(Common):
         global notebook_info
         notebook_info = get_current_notebook()
 
+    def get_run_meta(self):
+        global run_meta
+        return run_meta
+
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
             self.shap_on = model_monitor
@@ -282,7 +288,8 @@ class accuinsight(Common):
             end_time = int(get_time.now().timestamp()*1000)
             delta_ts = end_time - start_time
 
-            clear_runs(start_time, end_time, delta_ts)
+            global run_meta
+            run_meta = clear_runs(start_time, end_time, delta_ts)
 
             accuinsight._send_message(metric=None,
                                       current_value=None,
@@ -295,7 +302,7 @@ class accuinsight(Common):
             modeler_rest = LifecycleRestApi(env_value[LcConst.BACK_END_API_URL],
                                             env_value[LcConst.BACK_END_API_PORT],
                                             env_value[LcConst.BACK_END_API_URI])
-            modeler_rest.lc_create_run()
+            modeler_rest.lc_create_run(run_meta)
 
         def log_params(self, param=None):
             # sklearn/xgboost/lightgbm
