@@ -8,11 +8,12 @@ from collections import OrderedDict
 
 import boto3
 from hdfs3 import HDFileSystem
+from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_or_create_run_directory
+from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.core.LcConst.LcConst import ENV_JUPYTER_HOME_DIR
 from Accuinsight.modeler.utils.runs_utils import ProgressPercentage
 from Accuinsight.modeler.clients.modeler_api import WorkspaceRestApi
 from Accuinsight.modeler.utils.os_getenv import get_os_env, get_current_notebook
-from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.entities.alarm import Alarm
 
 
@@ -143,7 +144,7 @@ class Common(object):
 
             ## path for saving data
             save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_hdfs')
-            if os.path.exists(save_dir) == False:
+            if not os.path.exists(save_dir):
                 os.mkdir(save_dir)
             else:
                 pass
@@ -297,7 +298,7 @@ class Common(object):
     @staticmethod
     def get_current_run_id():
         try:
-            with open('/home/work/runs/run_info.json') as json_file:
+            with open(get_or_create_run_directory() + 'run_info.json') as json_file:
                 return json.load(json_file)['run_name']
         except FileNotFoundError or KeyError:
             return ''
