@@ -35,8 +35,16 @@ class accuinsight(Common):
     def get_file(self, storage_json_file_name=None):
         super().get_file(storage_json_file_name)
 
+    @staticmethod
+    def get_run_meta():
+        global run_meta
+        try:
+            return run_meta
+        except NameError:
+            return None
+
     def autolog(self, tag=None, best_weights=False, model_monitor=False):
-        global description, endpoint, var_model_file_path, message, thresholds, run_id, alarm, alarm_api, shap_on
+        global description, endpoint, var_model_file_path, message, thresholds, run_id, alarm, alarm_api, shap_on, run_meta
         description = tag
         endpoint = self.endpoint
         message = self.message
@@ -68,6 +76,7 @@ class accuinsight(Common):
         else:
             shap_on = False
         run_id = None
+        run_meta = None
 
         # if in notebook
         if is_in_ipython():
@@ -248,7 +257,8 @@ class accuinsight(Common):
                 end_ts = int(end.timestamp())
                 delta_ts = end_ts - start_ts
 
-                clear_runs(start_ts, end_ts, delta_ts)
+                global run_meta
+                run_meta = clear_runs(start_ts, end_ts, delta_ts)
                 accuinsight._send_message(metric=self.monitor,
                                           current_value=self.current_value,
                                           message=message,
@@ -259,7 +269,7 @@ class accuinsight(Common):
                 modeler_rest = LifecycleRestApi(env_value[LcConst.BACK_END_API_URL],
                                                 env_value[LcConst.BACK_END_API_PORT],
                                                 env_value[LcConst.BACK_END_API_URI])
-                modeler_rest.lc_create_run()
+                modeler_rest.lc_create_run(run_meta)
                 accuinsight.off_autolog()
 
         class visualCallbacks(keras.callbacks.Callback):
@@ -391,11 +401,9 @@ class accuinsight(Common):
         settings = gorilla.Settings(allow_hit=True, store_hit=True)
         gorilla.apply(gorilla.Patch(keras.Model, 'fit', fit, settings=settings))
 
-
     def off_autolog():
         def stop_log(self, original, args, kwargs, unlogged_params):
-            fit_model = original(self, *args, **kwargs)
-            return(fit_model)
+            return original(self, *args, **kwargs)
 
         @gorilla.patch(keras.Model)
         def fit(self, *args, **kwargs):
