@@ -36,8 +36,16 @@ class accuinsight(Common):
     def get_file(self, storage_json_file_name=None):
         super().get_file(storage_json_file_name)
 
+    @staticmethod
+    def get_run_meta():
+        global run_meta
+        try:
+            return run_meta
+        except NameError:
+            return None
+
     def autolog(self, tag=None, best_weights=False, model_monitor=False):
-        global description, endpoint, var_model_file_path, message, thresholds, best_weights_on, run_id, alarm, alarm_api, shap_on, feature_name
+        global description, endpoint, var_model_file_path, message, thresholds, best_weights_on, run_id, alarm, alarm_api, shap_on, feature_name, run_meta
         description = tag
         endpoint = self.endpoint
         message = self.message
@@ -69,6 +77,7 @@ class accuinsight(Common):
         else:
             shap_on = False
         run_id = None
+        run_meta = None
 
         if is_in_ipython():
             var_model_file_path = self.notebook_info
@@ -137,8 +146,6 @@ class accuinsight(Common):
 
                 set_run_name(self.model_summary['model_type'], self.model_summary['run_id'])
                 set_python_dependencies(py_depenpency=dependencies)
-
-#                print('dict_path: ', self.dict_path)         ######################
         
             '''[get best model] on_epoch_end '''
             def on_epoch_end(self, epoch, logs=None):
@@ -249,7 +256,8 @@ class accuinsight(Common):
                 end_ts = int(end.timestamp())
                 delta_ts = end_ts - start_ts
 
-                clear_runs(start_ts, end_ts, delta_ts)
+                global run_meta
+                run_meta = clear_runs(start_ts, end_ts, delta_ts)
                 accuinsight._send_message(metric=self.monitor,
                                           current_value=self.current_value,
                                           message=message,
@@ -259,7 +267,7 @@ class accuinsight(Common):
                 modeler_rest = LifecycleRestApi(env_value[LcConst.BACK_END_API_URL],
                                                 env_value[LcConst.BACK_END_API_PORT],
                                                 env_value[LcConst.BACK_END_API_URI])
-                modeler_rest.lc_create_run()
+                modeler_rest.lc_create_run(run_meta)
                 accuinsight._off_autolog()
 
         class visualCallbacks(tensorflow.keras.callbacks.Callback):
@@ -382,8 +390,7 @@ class accuinsight(Common):
 
     def _off_autolog():
         def stop_log(self, original, args, kwargs, unlogged_params):
-            fit_model = original(self, *args, **kwargs)
-            return fit_model
+            return original(self, *args, **kwargs)
 
         @gorilla.patch(tensorflow.keras.Model)
         def fit(self, *args, **kwargs):
